@@ -253,7 +253,6 @@ Drivers:
     vertica
     ydb
     turso
-    duckdb
 
 Examples:
     goose sqlite3 ./foo.db status
@@ -270,8 +269,7 @@ Examples:
     goose clickhouse "tcp://127.0.0.1:9000" status
     goose vertica "vertica://user:password@localhost:5433/dbname?connection_load_balance=1" status
     goose ydb "grpcs://localhost:2135/local?go_query_mode=scripting&go_fake_tx=scripting&go_query_bind=declare,numeric" status
-    goose turso "libsql://dbname.turso.io?authToken=token" status
-    goose duckdb ./foo.db status
+	goose turso "libsql://dbname.turso.io?authToken=token" status
 
     GOOSE_DRIVER=sqlite3 GOOSE_DBSTRING=./foo.db goose status
     GOOSE_DRIVER=sqlite3 GOOSE_DBSTRING=./foo.db goose create init sql
@@ -279,7 +277,6 @@ Examples:
     GOOSE_DRIVER=mysql GOOSE_DBSTRING="user:password@/dbname" goose status
     GOOSE_DRIVER=redshift GOOSE_DBSTRING="postgres://user:password@qwerty.us-east-1.redshift.amazonaws.com:5439/db" goose status
     GOOSE_DRIVER=turso GOOSE_DBSTRING="libsql://dbname.turso.io?authToken=token" goose status
-    GOOSE_DRIVER=duckdb GOOSE_DBSTRING=./foo.db goose status
 
 Options:
 `
